__version__ = '0.1.1'
from .neattext import TextCleaner
from .neattext import TextExtractor
from .neattext import TextMetrics
from .neattext import TextFrame

# import neattext.functions ##worked
from neattext.functions import *
from neattext.pattern_data import *
from neattext.explainer import *



